==> owlapi-impl-3.4.10-sources.jar: org/semanticweb/owlapi/reasoner/impl/OWLObjectPropertyNodeSet.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.reasoner.impl;

import java.util.Set;

import org.semanticweb.owlapi.model.OWLObjectPropertyExpression;
import org.semanticweb.owlapi.reasoner.Node;

/** @author Matthew Horridge, The University of Manchester, Information Management
 *         Group, Date: 05-Dec-2009 */
public class OWLObjectPropertyNodeSet extends DefaultNodeSet<OWLObjectPropertyExpression> {
    /** default constructor. */
    public OWLObjectPropertyNodeSet() {}

    /** @param entity
     *            property to include */
    public OWLObjectPropertyNodeSet(OWLObjectPropertyExpression entity) {
        super(entity);
    }

    /** @param owlObjectPropertyNode
     *            property node to include */
    public OWLObjectPropertyNodeSet(
            Node<OWLObjectPropertyExpression> owlObjectPropertyNode) {
        super(owlObjectPropertyNode);
    }

    /** @param nodes
     *            nodes to include */
    public OWLObjectPropertyNodeSet(Set<Node<OWLObjectPropertyExpression>> nodes) {
        super(nodes);
    }

    @Override
    protected DefaultNode<OWLObjectPropertyExpression> getNode(
            OWLObjectPropertyExpression entity) {
        return NodeFactory.getOWLObjectPropertyNode(entity);
    }

    @Override
    protected DefaultNode<OWLObjectPropertyExpression> getNode(
            Set<OWLObjectPropertyExpression> entities) {
        return NodeFactory.getOWLObjectPropertyNode(entities);
    }
}

==> owlapi-impl-3.5.2-sources.jar: org/semanticweb/owlapi/reasoner/impl/OWLObjectPropertyNodeSet.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.reasoner.impl;

import java.util.Set;

import org.semanticweb.owlapi.model.OWLObjectPropertyExpression;
import org.semanticweb.owlapi.reasoner.Node;

/**
 * @author Matthew Horridge, The University of Manchester, Information Management
 *         Group, Date: 05-Dec-2009
 */
public class OWLObjectPropertyNodeSet extends
        DefaultNodeSet<OWLObjectPropertyExpression> {

    /** default constructor. */
    public OWLObjectPropertyNodeSet() {}

    /**
     * @param entity
     *        property to include
     */
    public OWLObjectPropertyNodeSet(OWLObjectPropertyExpression entity) {
        super(entity);
    }

    /**
     * @param owlObjectPropertyNode
     *        property node to include
     */
    public OWLObjectPropertyNodeSet(
            Node<OWLObjectPropertyExpression> owlObjectPropertyNode) {
        super(owlObjectPropertyNode);
    }

    /**
     * @param nodes
     *        nodes to include
     */
    public OWLObjectPropertyNodeSet(Set<Node<OWLObjectPropertyExpression>> nodes) {
        super(nodes);
    }

    @Override
    protected DefaultNode<OWLObjectPropertyExpression> getNode(
            OWLObjectPropertyExpression entity) {
        return NodeFactory.getOWLObjectPropertyNode(entity);
    }

    @Override
    protected DefaultNode<OWLObjectPropertyExpression> getNode(
            Set<OWLObjectPropertyExpression> entities) {
        return NodeFactory.getOWLObjectPropertyNode(entities);
    }
}
